# generated by datamodel-codegen:
#   filename:  embedding_v1.json
#   timestamp: 2025-12-12T07:02:32+00:00

from __future__ import annotations

from pydantic import BaseModel, ConfigDict, Field


class EmbeddingV1(BaseModel):
    """
    Universal schema for embedding responses across all Lumen services (face, clip, ocr, etc.)
    """

    model_config = ConfigDict(
        extra='forbid',
    )
    vector: list[float] = Field(..., min_length=1)
    """
    Embedding vector
    """
    dim: int = Field(..., ge=1)
    """
    Embedding dimension
    """
    model_id: str = Field(..., min_length=1)
    """
    Model identifier that generated the embedding
    """
