# generated by datamodel-codegen:
#   filename:  result_schemas
#   timestamp: 2025-12-12T07:02:32+00:00

from .embedding_v1 import EmbeddingV1
from .face_v1 import FaceV1
from .labels_v1 import LabelsV1
from .ocr_v1 import OCRV1
from .text_generation_v1 import TextGenerationV1

__all__ = ["FaceV1", "EmbeddingV1", "LabelsV1", "OCRV1", "TextGenerationV1"]
